##  Activating a Calculation Template
Follow these steps:
  1. In the administration area, go to the Calculations section.
  2. Click New Calculation.
  3. In the Templates section, find the template you need and click Use Template.
![Selecting a Calculation Template](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274f40c37a441014a888d72d430f6ba8_LowRes.png)
Selecting a Calculation Template
  4. On the calculation page, adjust the configuration as needed, then click Save and Activate.
